Portia
======

.. image:: https://img.shields.io/travis/praekelt/portia.svg
        :target: https://travis-ci.org/praekelt/portia

.. image:: https://img.shields.io/pypi/v/portia.svg
        :target: https://pypi.python.org/pypi/portia

.. image:: https://coveralls.io/repos/praekelt/portia/badge.png?branch=develop
    :target: https://coveralls.io/r/praekelt/portia?branch=develop
    :alt: Code Coverage

.. image:: https://readthedocs.org/projects/portia/badge/?version=latest
    :target: https://portiadb.readthedocs.org
    :alt: Portia Docs

`Number porting database <http://portiadb.rtfd.org>`_
